You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@polygene.apache.org by ni...@apache.org on 2015/07/30 21:49:05 UTC

[66/80] zest-java git commit: Tightening everything up after massive namespace change. Removal of practically all "Qi4j" names and references.

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/build.gradle
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/build.gradle b/samples/dci-cargo/dcisample_b/build.gradle
index ca9961a..19defbc 100644
--- a/samples/dci-cargo/dcisample_b/build.gradle
+++ b/samples/dci-cargo/dcisample_b/build.gradle
@@ -23,21 +23,21 @@ jar { manifest { name = "Apache Zest™ Sample DCI Cargo - Sample B" }}
 
 dependencies {
 
-  compile project( ':org.qi4j.core:org.qi4j.core.bootstrap' )
-  compile project( ':org.qi4j.libraries:org.qi4j.library.constraints' )
-  compile project( ':org.qi4j.libraries:org.qi4j.library.conversion' )
-  compile project( ':org.qi4j.extensions:org.qi4j.extension.valueserialization-orgjson' )
-  compile project( ':org.qi4j.extensions:org.qi4j.extension.indexing-rdf' )
-  compile project( ':org.qi4j.tools:org.qi4j.tool.envisage' )
+  compile project( ':org.apache.zest.core:org.apache.zest.core.bootstrap' )
+  compile project( ':org.apache.zest.libraries:org.apache.zest.library.constraints' )
+  compile project( ':org.apache.zest.libraries:org.apache.zest.library.conversion' )
+  compile project( ':org.apache.zest.extensions:org.apache.zest.extension.valueserialization-orgjson' )
+  compile project( ':org.apache.zest.extensions:org.apache.zest.extension.indexing-rdf' )
+  compile project( ':org.apache.zest.tools:org.apache.zest.tool.envisage' )
   compile libraries.jetty_webapp
   compile libraries.wicket
   compile libraries.wicket_devutils
   compile libraries.wicket_stateless
   compile libraries.slf4j_api
 
-  runtime project( ':org.qi4j.core:org.qi4j.core.runtime' )
+  runtime project( ':org.apache.zest.core:org.apache.zest.core.runtime' )
 
-  testCompile project( ':org.qi4j.core:org.qi4j.core.testsupport' )
+  testCompile project( ':org.apache.zest.core:org.apache.zest.core.testsupport' )
   testCompile libraries.easymock
 
   testRuntime libraries.logback
@@ -45,6 +45,6 @@ dependencies {
 }
 
 task(runSample, dependsOn: 'testClasses', type: JavaExec) {
-    main = 'org.qi4j.sample.dcicargo.sample_b.bootstrap.Start8082'
+    main = 'org.apache.zest.sample.dcicargo.sample_b.bootstrap.Start8082'
     classpath = sourceSets.test.runtimeClasspath
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/DCISampleApplication_b.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/DCISampleApplication_b.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/DCISampleApplication_b.java
index 7ed812d..38ffc43 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/DCISampleApplication_b.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/DCISampleApplication_b.java
@@ -30,7 +30,7 @@ import org.apache.zest.sample.dcicargo.sample_b.communication.web.booking.ReRout
 import org.apache.zest.sample.dcicargo.sample_b.communication.web.booking.RouteCargoPage;
 import org.apache.zest.sample.dcicargo.sample_b.communication.web.handling.IncidentLoggingApplicationMockupPage;
 import org.apache.zest.sample.dcicargo.sample_b.communication.web.tracking.TrackCargoPage;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.WicketQi4jApplication;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.WicketZestApplication;
 import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.tabs.TabsPanel;
 
 /**
@@ -39,7 +39,7 @@ import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.tabs.TabsP
  * A Wicket application backed by Zest.
  */
 public class DCISampleApplication_b
-    extends WicketQi4jApplication
+    extends WicketZestApplication
 {
     public void wicketInit()
     {

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/VisualizeApplicationStructure.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/VisualizeApplicationStructure.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/VisualizeApplicationStructure.java
index 9d9190d..1a412be 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/VisualizeApplicationStructure.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/VisualizeApplicationStructure.java
@@ -30,10 +30,10 @@ public class VisualizeApplicationStructure
     public static void main( String[] args )
         throws Exception
     {
-        Energy4Java qi4j = new Energy4Java();
+        Energy4Java zest = new Energy4Java();
         Assembler assembler = new Assembler();
-        ApplicationDescriptor applicationModel = qi4j.newApplicationModel( assembler );
-        applicationModel.newInstance( qi4j.spi() );
+        ApplicationDescriptor applicationModel = zest.newApplicationModel( assembler );
+        applicationModel.newInstance( zest.spi() );
 
         /*
        * The Envisage Swing app visualizes the application assemblage structure.

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/assembly/Assembler.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/assembly/Assembler.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/assembly/Assembler.java
index 3e3afff..b187630 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/assembly/Assembler.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/bootstrap/assembly/Assembler.java
@@ -90,8 +90,6 @@ import static org.apache.zest.api.structure.Application.Mode.development;
  * in the CONTEXT-RoleMapCandidates module. Note that there are still no "physical" upward dependencies
  * from the data package (containing entities and values) to layers above.
  *
- * See more at http://www.qi4j.org/qi4j/70.html
- *
  * TRY THIS:
  * Run VisualizeApplicationStructure to see a cool visualization of the assembly!
  */

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.java
index d9575e6..ed3c346 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.java
@@ -25,7 +25,7 @@ import org.apache.wicket.markup.html.link.Link;
 import org.apache.wicket.markup.html.panel.Fragment;
 import org.apache.wicket.model.Model;
 import org.apache.wicket.request.mapper.parameter.PageParameters;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.WicketQi4jApplication;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.WicketZestApplication;
 import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.page.BaseWebPage;
 import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.tabs.TabsPanel;
 //import org.wicketstuff.stateless.StatelessAjaxFallbackLink;
@@ -69,7 +69,7 @@ public class BasePage extends BaseWebPage
         add( toggleLinks );
         add( links.setOutputMarkupPlaceholderTag( true ).setVisible( false ) );
 
-        add( new Label( "version", ( (WicketQi4jApplication) getApplication() ).appVersion() ) );
+        add( new Label( "version", ( (WicketZestApplication) getApplication() ).appVersion() ) );
 
         add( new TabsPanel( activeTab ) );
     }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketQi4jApplication.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketQi4jApplication.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketQi4jApplication.java
deleted file mode 100644
index e20670a..0000000
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketQi4jApplication.java
+++ /dev/null
@@ -1,236 +0,0 @@
-/*
- * Copyright 2011 Marc Grue.
- *
- * Licensed  under the  Apache License,  Version 2.0  (the "License");
- * you may not use  this file  except in  compliance with the License.
- * You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed  under the  License is distributed on an "AS IS" BASIS,
- * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
- * implied.
- *
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.zest.sample.dcicargo.sample_b.infrastructure;
-
-import javax.servlet.http.HttpServletRequest;
-import org.apache.wicket.Page;
-import org.apache.wicket.protocol.http.WebApplication;
-import org.apache.wicket.request.cycle.AbstractRequestCycleListener;
-import org.apache.wicket.request.cycle.RequestCycle;
-import org.apache.zest.api.Qi4j;
-import org.apache.zest.api.injection.scope.Service;
-import org.apache.zest.api.injection.scope.Structure;
-import org.apache.zest.api.structure.Application;
-import org.apache.zest.api.structure.Module;
-import org.apache.zest.api.unitofwork.UnitOfWork;
-import org.apache.zest.api.unitofwork.UnitOfWorkCompletionException;
-import org.apache.zest.api.usecase.UsecaseBuilder;
-import org.apache.zest.bootstrap.ApplicationAssembler;
-import org.apache.zest.bootstrap.Energy4Java;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.conversion.EntityToDTOService;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.dci.Context;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.model.Queries;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.model.ReadOnlyModel;
-import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.page.BaseWebPage;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-/**
- * WicketQi4jApplication
- *
- * Base Wicket Web Application containing the Zest application.
- */
-public class WicketQi4jApplication
-    extends WebApplication
-{
-    public Logger logger = LoggerFactory.getLogger( WicketQi4jApplication.class );
-
-    protected Application qi4jApp;
-    protected Module qi4jModule;
-
-    @Structure
-    protected Module module;
-
-    @Structure
-    protected Qi4j qi4j;
-
-    @Service
-    protected EntityToDTOService valueConverter;
-
-    /**
-     * Zest Assembler
-     *
-     * To let the custom application class (DCISampleApplication_x) focus on starting up the
-     * Wicket environment, I made a convention of having Zest Assembler files in an 'assembly'
-     * folder beside the custom application class.
-     *
-     * There's always only one application file, but we could split the assemblage into several
-     * files ie. one for each layer. In that case, the Assembler file would be distributing to
-     * the individual LayerXAssembler classes.
-     *
-     * If you like, you can also override this method in the custom application class and simply
-     * return an instance of YourAssembler:
-     * <pre><code>
-     * &#64;Override protected ApplicationAssembler getAssembler() {
-     *     return new YourAssemblerInAnyPath();
-     * }
-     * </code></pre>
-     */
-    protected ApplicationAssembler getAssembler()
-        throws Exception
-    {
-        String appPath = getClass().getCanonicalName();
-        String expectedPathFromApplication = ".assembly.Assembler";
-        String assemblerPath = appPath.substring( 0, appPath.lastIndexOf( "." ) ) + expectedPathFromApplication;
-        try
-        {
-            return (ApplicationAssembler) Class.forName( assemblerPath ).newInstance();
-        }
-        catch( ClassNotFoundException e )
-        {
-            throw new Exception( "Couldn't find Zest assembler in path '" + assemblerPath + "'" );
-        }
-    }
-
-    protected String defaultLayerName()
-    {
-        return "BOOTSTRAP";
-    }
-
-    protected String defaultModuleName()
-    {
-        return "BOOTSTRAP-Bootstrap";
-    }
-
-    // Override this to bootstrap the wicket application
-    protected void wicketInit()
-    {
-    }
-
-    @Override
-    protected void init()
-    {
-        startQi4j();
-        handleUnitOfWork();
-
-        Context.prepareContextBaseClass( module );
-        BaseWebPage.prepareBaseWebPageClass( module );
-        ReadOnlyModel.prepareModelBaseClass( qi4jModule, qi4j, valueConverter );
-        Queries.prepareQueriesBaseClass( module, module );
-
-        wicketInit();
-    }
-
-    private void startQi4j()
-    {
-        try
-        {
-            logger.info( "Starting Zest application" );
-            Energy4Java qi4j = new Energy4Java();
-            qi4jApp = qi4j.newApplication( getAssembler() );
-            qi4jApp.activate();
-            qi4jModule = qi4jApp.findModule( defaultLayerName(), defaultModuleName() );
-
-            // Zest injects @Structure and @Service elements into this application instance
-            qi4jModule.injectTo( this );
-
-            logger.info( "Started Zest application" );
-        }
-        catch( Exception e )
-        {
-            logger.error( "Could not start Zest application." );
-            e.printStackTrace();
-            System.exit( 100 );
-        }
-    }
-
-    private void handleUnitOfWork()
-    {
-        getRequestCycleListeners().add( new AbstractRequestCycleListener()
-        {
-            @Override
-            public void onBeginRequest( final RequestCycle requestCycle )
-            {
-                super.onBeginRequest( requestCycle );
-
-                logger.debug( "================================" );
-                logger.debug( "REQUEST start" );
-                logger.debug( requestCycle.getRequest().toString() );
-                logger.debug( requestCycle.getRequest().getRequestParameters().toString() );
-
-                UnitOfWork uow = module.newUnitOfWork( UsecaseBuilder.newUsecase( "REQUEST" ) );
-                logger.debug( "  ### NEW " + uow + "   ### MODULE: " + qi4jModule );
-            }
-
-            @Override
-            public void onEndRequest( final RequestCycle requestCycle )
-            {
-                UnitOfWork uow = module.currentUnitOfWork();
-                if( uow != null )
-                {
-                    try
-                    {
-                        if( "POST".equals( ( (HttpServletRequest) requestCycle.getRequest()
-                            .getContainerRequest() ).getMethod() ) )
-                        {
-                            // "Save"
-                            logger.debug( "  ### COMPLETE " + uow + "   ### MODULE: " + qi4jModule );
-                            uow.complete();
-                        }
-                        else
-                        {
-                            // GET requests
-                            logger.debug( "  ### DISCARD " + uow + "   ### MODULE: " + qi4jModule );
-                            uow.discard();
-                        }
-                    }
-                    catch( UnitOfWorkCompletionException e )
-                    {
-                        logger.error( "  ### DISCARD " + uow + "   ### MODULE: " + qi4jModule );
-                        uow.discard();
-                        e.printStackTrace();
-                    }
-                }
-                logger.debug( "REQUEST end" );
-                logger.debug( "------------------------------------" );
-            }
-        } );
-    }
-
-    // Since Zest can only add concrete classes in the assembly, we need to implement a (dummy) getHomePage()
-    // method here. Override in wicket application class with a real returned page class.
-    @Override
-    public Class<? extends Page> getHomePage()
-    {
-        return null;
-    }
-
-    @Override
-    protected void onDestroy()
-    {
-        if( qi4jApp == null )
-        {
-            return;
-        }
-
-        try
-        {
-            logger.info( "Passivating Zest application" );
-            qi4jApp.passivate();
-        }
-        catch( Exception e )
-        {
-            e.printStackTrace();
-        }
-    }
-
-    public String appVersion()
-    {
-        return qi4jApp.version();
-    }
-}
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketZestApplication.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketZestApplication.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketZestApplication.java
new file mode 100644
index 0000000..55ceeab
--- /dev/null
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/WicketZestApplication.java
@@ -0,0 +1,236 @@
+/*
+ * Copyright 2011 Marc Grue.
+ *
+ * Licensed  under the  Apache License,  Version 2.0  (the "License");
+ * you may not use  this file  except in  compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed  under the  License is distributed on an "AS IS" BASIS,
+ * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
+ * implied.
+ *
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.zest.sample.dcicargo.sample_b.infrastructure;
+
+import javax.servlet.http.HttpServletRequest;
+import org.apache.wicket.Page;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.request.cycle.AbstractRequestCycleListener;
+import org.apache.wicket.request.cycle.RequestCycle;
+import org.apache.zest.api.ZestAPI;
+import org.apache.zest.api.injection.scope.Service;
+import org.apache.zest.api.injection.scope.Structure;
+import org.apache.zest.api.structure.Application;
+import org.apache.zest.api.structure.Module;
+import org.apache.zest.api.unitofwork.UnitOfWork;
+import org.apache.zest.api.unitofwork.UnitOfWorkCompletionException;
+import org.apache.zest.api.usecase.UsecaseBuilder;
+import org.apache.zest.bootstrap.ApplicationAssembler;
+import org.apache.zest.bootstrap.Energy4Java;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.conversion.EntityToDTOService;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.dci.Context;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.model.Queries;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.model.ReadOnlyModel;
+import org.apache.zest.sample.dcicargo.sample_b.infrastructure.wicket.page.BaseWebPage;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+/**
+ * WicketZestApplication
+ *
+ * Base Wicket Web Application containing the Zest application.
+ */
+public class WicketZestApplication
+    extends WebApplication
+{
+    public Logger logger = LoggerFactory.getLogger( WicketZestApplication.class );
+
+    protected Application zestApp;
+    protected Module zestModule;
+
+    @Structure
+    protected Module module;
+
+    @Structure
+    protected ZestAPI api;
+
+    @Service
+    protected EntityToDTOService valueConverter;
+
+    /**
+     * Zest Assembler
+     *
+     * To let the custom application class (DCISampleApplication_x) focus on starting up the
+     * Wicket environment, I made a convention of having Zest Assembler files in an 'assembly'
+     * folder beside the custom application class.
+     *
+     * There's always only one application file, but we could split the assemblage into several
+     * files ie. one for each layer. In that case, the Assembler file would be distributing to
+     * the individual LayerXAssembler classes.
+     *
+     * If you like, you can also override this method in the custom application class and simply
+     * return an instance of YourAssembler:
+     * <pre><code>
+     * &#64;Override protected ApplicationAssembler getAssembler() {
+     *     return new YourAssemblerInAnyPath();
+     * }
+     * </code></pre>
+     */
+    protected ApplicationAssembler getAssembler()
+        throws Exception
+    {
+        String appPath = getClass().getCanonicalName();
+        String expectedPathFromApplication = ".assembly.Assembler";
+        String assemblerPath = appPath.substring( 0, appPath.lastIndexOf( "." ) ) + expectedPathFromApplication;
+        try
+        {
+            return (ApplicationAssembler) Class.forName( assemblerPath ).newInstance();
+        }
+        catch( ClassNotFoundException e )
+        {
+            throw new Exception( "Couldn't find Zest assembler in path '" + assemblerPath + "'" );
+        }
+    }
+
+    protected String defaultLayerName()
+    {
+        return "BOOTSTRAP";
+    }
+
+    protected String defaultModuleName()
+    {
+        return "BOOTSTRAP-Bootstrap";
+    }
+
+    // Override this to bootstrap the wicket application
+    protected void wicketInit()
+    {
+    }
+
+    @Override
+    protected void init()
+    {
+        startZest();
+        handleUnitOfWork();
+
+        Context.prepareContextBaseClass( module );
+        BaseWebPage.prepareBaseWebPageClass( module );
+        ReadOnlyModel.prepareModelBaseClass( zestModule, api, valueConverter );
+        Queries.prepareQueriesBaseClass( module, module );
+
+        wicketInit();
+    }
+
+    private void startZest()
+    {
+        try
+        {
+            logger.info( "Starting Zest application" );
+            Energy4Java zest = new Energy4Java();
+            zestApp = zest.newApplication( getAssembler() );
+            zestApp.activate();
+            zestModule = zestApp.findModule( defaultLayerName(), defaultModuleName() );
+
+            // Zest injects @Structure and @Service elements into this application instance
+            zestModule.injectTo( this );
+
+            logger.info( "Started Zest application" );
+        }
+        catch( Exception e )
+        {
+            logger.error( "Could not start Zest application." );
+            e.printStackTrace();
+            System.exit( 100 );
+        }
+    }
+
+    private void handleUnitOfWork()
+    {
+        getRequestCycleListeners().add( new AbstractRequestCycleListener()
+        {
+            @Override
+            public void onBeginRequest( final RequestCycle requestCycle )
+            {
+                super.onBeginRequest( requestCycle );
+
+                logger.debug( "================================" );
+                logger.debug( "REQUEST start" );
+                logger.debug( requestCycle.getRequest().toString() );
+                logger.debug( requestCycle.getRequest().getRequestParameters().toString() );
+
+                UnitOfWork uow = module.newUnitOfWork( UsecaseBuilder.newUsecase( "REQUEST" ) );
+                logger.debug( "  ### NEW " + uow + "   ### MODULE: " + zestModule );
+            }
+
+            @Override
+            public void onEndRequest( final RequestCycle requestCycle )
+            {
+                UnitOfWork uow = module.currentUnitOfWork();
+                if( uow != null )
+                {
+                    try
+                    {
+                        if( "POST".equals( ( (HttpServletRequest) requestCycle.getRequest()
+                            .getContainerRequest() ).getMethod() ) )
+                        {
+                            // "Save"
+                            logger.debug( "  ### COMPLETE " + uow + "   ### MODULE: " + zestModule );
+                            uow.complete();
+                        }
+                        else
+                        {
+                            // GET requests
+                            logger.debug( "  ### DISCARD " + uow + "   ### MODULE: " + zestModule );
+                            uow.discard();
+                        }
+                    }
+                    catch( UnitOfWorkCompletionException e )
+                    {
+                        logger.error( "  ### DISCARD " + uow + "   ### MODULE: " + zestModule );
+                        uow.discard();
+                        e.printStackTrace();
+                    }
+                }
+                logger.debug( "REQUEST end" );
+                logger.debug( "------------------------------------" );
+            }
+        } );
+    }
+
+    // Since Zest can only add concrete classes in the assembly, we need to implement a (dummy) getHomePage()
+    // method here. Override in wicket application class with a real returned page class.
+    @Override
+    public Class<? extends Page> getHomePage()
+    {
+        return null;
+    }
+
+    @Override
+    protected void onDestroy()
+    {
+        if( zestApp == null )
+        {
+            return;
+        }
+
+        try
+        {
+            logger.info( "Passivating Zest application" );
+            zestApp.passivate();
+        }
+        catch( Exception e )
+        {
+            e.printStackTrace();
+        }
+    }
+
+    public String appVersion()
+    {
+        return zestApp.version();
+    }
+}
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/conversion/EntityToDTOService.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/conversion/EntityToDTOService.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/conversion/EntityToDTOService.java
index 80b92b0..9d6b166 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/conversion/EntityToDTOService.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/conversion/EntityToDTOService.java
@@ -41,14 +41,14 @@ import org.apache.zest.api.value.ValueDescriptor;
 import org.apache.zest.functional.Function;
 import org.apache.zest.functional.Iterables;
 import org.apache.zest.library.conversion.values.Unqualified;
-import org.apache.zest.spi.Qi4jSPI;
+import org.apache.zest.spi.ZestSPI;
 
 /**
  * Conversion of Entity objects to DTO's
  *
  * Value composites that extend {@link DTO} will have association properties converted recursively.
  *
- * Modification of {org.qi4j.library.conversion.values.EntityToValue}
+ * Modification of {org.apache.zest.library.conversion.values.EntityToValue}
  * WARN No support of NamedAssociations
  */
 @SuppressWarnings( "unchecked" )
@@ -65,7 +65,7 @@ public interface EntityToDTOService
         private ValueBuilderFactory vbf;
 
         @Structure
-        private Qi4jSPI spi;
+        private ZestSPI spi;
 
         @Structure
         private Module module;

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/JSONModel.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/JSONModel.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/JSONModel.java
index e8756c6..aa9a2d9 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/JSONModel.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/JSONModel.java
@@ -48,7 +48,7 @@ public class JSONModel<T, U extends ValueComposite>
         }
 
         // Get ValueComposite interface
-        Class<U> valueCompositeClass = (Class<U>) qi4j.valueDescriptorFor( value ).valueType().mainType();
+        Class<U> valueCompositeClass = (Class<U>) api.valueDescriptorFor( value ).valueType().mainType();
 
         return new JSONModel<T, U>( value, valueCompositeClass );
     }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/ReadOnlyModel.java
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/ReadOnlyModel.java b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/ReadOnlyModel.java
index 92873be..fb99ade 100644
--- a/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/ReadOnlyModel.java
+++ b/samples/dci-cargo/dcisample_b/src/main/java/org/apache/zest/sample/dcicargo/sample_b/infrastructure/model/ReadOnlyModel.java
@@ -18,7 +18,7 @@
 package org.apache.zest.sample.dcicargo.sample_b.infrastructure.model;
 
 import org.apache.wicket.model.IModel;
-import org.apache.zest.api.Qi4j;
+import org.apache.zest.api.ZestAPI;
 import org.apache.zest.api.structure.Module;
 import org.apache.zest.sample.dcicargo.sample_b.infrastructure.conversion.EntityToDTOService;
 
@@ -33,7 +33,7 @@ public abstract class ReadOnlyModel<T>
     private static final long serialVersionUID = 1L;
 
     static protected EntityToDTOService valueConverter;
-    static protected Qi4j qi4j;
+    static protected ZestAPI api;
     static protected Module module;
 
     /**
@@ -60,12 +60,12 @@ public abstract class ReadOnlyModel<T>
     }
 
     public static void prepareModelBaseClass( Module m,
-                                              Qi4j api,
+                                              ZestAPI api,
                                               EntityToDTOService entityToDTO
     )
     {
         module = m;
-        qi4j = api;
+        ReadOnlyModel.api = api;
         valueConverter = entityToDTO;
     }
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/resources/log4j.properties
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/resources/log4j.properties b/samples/dci-cargo/dcisample_b/src/main/resources/log4j.properties
index f212fe5..a1d1edd 100644
--- a/samples/dci-cargo/dcisample_b/src/main/resources/log4j.properties
+++ b/samples/dci-cargo/dcisample_b/src/main/resources/log4j.properties
@@ -26,4 +26,4 @@ log4j.rootLogger=INFO,Stdout
 #log4j.logger.org.apache.wicket.RequestCycle=DEBUG
 #log4j.logger.org.apache.wicket.util.resource=DEBUG
 
-#log4j.logger.org.qi4j.index.rdf.query.internal.RdfQueryParserImpl=DEBUG, Stdout
\ No newline at end of file
+#log4j.logger.org.apache.zest.index.rdf.query.internal.RdfQueryParserImpl=DEBUG, Stdout
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci-cargo/dcisample_b/src/main/resources/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.html
----------------------------------------------------------------------
diff --git a/samples/dci-cargo/dcisample_b/src/main/resources/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.html b/samples/dci-cargo/dcisample_b/src/main/resources/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.html
index 010b6f8..0b827ce 100644
--- a/samples/dci-cargo/dcisample_b/src/main/resources/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.html
+++ b/samples/dci-cargo/dcisample_b/src/main/resources/org/apache/zest/sample/dcicargo/sample_b/communication/web/BasePage.html
@@ -24,7 +24,7 @@
 <div class="left">
     <div class="headline"><a href="/">DCI sample</a></div>
     <div id="toggle">
-        <a href="#" class="closed" wicket:id="toggleLinks">Qi4j/Wicket port of the DDD sample application to the DCI
+        <a href="#" class="closed" wicket:id="toggleLinks">Apache Zest/Wicket port of the DDD sample application to the DCI
             paradigm.</a>
     </div>
 
@@ -36,8 +36,8 @@
             <tr>
                 <td>DCI</td>
                 <td>DDD</td>
-                <td>Qi4j</td>
-                <td>Wicket</td>
+                <td>Apache Zest</td>
+                <td>Apache Wicket</td>
                 <td>Marc Grue blog</td>
                 <td>Books</td>
             </tr>
@@ -92,7 +92,7 @@
 </div>
 
 <div class="right">
-    <b>Java-Qi4j-Wicket<br>
+    <b>Java-Zest-Wicket<br>
         Version <span wicket:id="version">[X.Y.Z]</span></b><br>
     Created 2011-10-04<br>
     Modified 2011-10-04<br>

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/dci/build.gradle
----------------------------------------------------------------------
diff --git a/samples/dci/build.gradle b/samples/dci/build.gradle
index 2d9ee86..9b9c09c 100644
--- a/samples/dci/build.gradle
+++ b/samples/dci/build.gradle
@@ -23,11 +23,11 @@ description = "Sample of how DCI (Data, Context & Interaction) pattern is implem
 jar { manifest { name = "Apache Zest™ Sample - DCI" }}
 
 dependencies {
-  compile(project(":org.qi4j.core:org.qi4j.core.bootstrap"))
-  compile(project(":org.qi4j.core:org.qi4j.core.runtime"))  /* TODO: Get rid of this dependency */
-  compile(project(":org.qi4j.libraries:org.qi4j.library.constraints"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.bootstrap"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.runtime"))  /* TODO: Get rid of this dependency */
+  compile(project(":org.apache.zest.libraries:org.apache.zest.library.constraints"))
 
-  testCompile(project(":org.qi4j.core:org.qi4j.core.testsupport"))
+  testCompile(project(":org.apache.zest.core:org.apache.zest.core.testsupport"))
   testCompile(libraries.easymock)
 
   testRuntime(libraries.logback)

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/forum/build.gradle
----------------------------------------------------------------------
diff --git a/samples/forum/build.gradle b/samples/forum/build.gradle
index c3e9ddd..667b852 100644
--- a/samples/forum/build.gradle
+++ b/samples/forum/build.gradle
@@ -23,21 +23,21 @@ jar { manifest { name = "Apache Zest™ Sample - Forum" }}
 
 dependencies {
 
-  compile project( ":org.qi4j.core:org.qi4j.core.bootstrap" )
-  compile project( ":org.qi4j.libraries:org.qi4j.library.rest-server" )
-  compile project( ":org.qi4j.libraries:org.qi4j.library.fileconfig" )
-  compile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-file" )
-  compile project( ":org.qi4j.extensions:org.qi4j.extension.valueserialization-orgjson" )
+  compile project( ":org.apache.zest.core:org.apache.zest.core.bootstrap" )
+  compile project( ":org.apache.zest.libraries:org.apache.zest.library.rest-server" )
+  compile project( ":org.apache.zest.libraries:org.apache.zest.library.fileconfig" )
+  compile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-file" )
+  compile project( ":org.apache.zest.extensions:org.apache.zest.extension.valueserialization-orgjson" )
   compile libraries.servlet_api
 
-  testCompile project( ":org.qi4j.core:org.qi4j.core.testsupport" )
+  testCompile project( ":org.apache.zest.core:org.apache.zest.core.testsupport" )
 
-  testRuntime project( ":org.qi4j.core:org.qi4j.core.runtime" )
+  testRuntime project( ":org.apache.zest.core:org.apache.zest.core.runtime" )
   testRuntime libraries.logback
 
 }
 
 task(runSample, dependsOn: 'testClasses', type: JavaExec) {
-    main = 'org.qi4j.samples.forum.web.Main'
+    main = 'org.apache.zest.samples.forum.web.Main'
     classpath = sourceSets.test.runtimeClasspath
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/forum/src/main/java/org/apache/zest/sample/forum/context/Context.java
----------------------------------------------------------------------
diff --git a/samples/forum/src/main/java/org/apache/zest/sample/forum/context/Context.java b/samples/forum/src/main/java/org/apache/zest/sample/forum/context/Context.java
index 3c915ca..df98475 100644
--- a/samples/forum/src/main/java/org/apache/zest/sample/forum/context/Context.java
+++ b/samples/forum/src/main/java/org/apache/zest/sample/forum/context/Context.java
@@ -18,7 +18,7 @@
  */
 package org.apache.zest.sample.forum.context;
 
-import org.apache.zest.api.Qi4j;
+import org.apache.zest.api.ZestAPI;
 import org.apache.zest.api.composite.Composite;
 import org.apache.zest.api.injection.scope.Structure;
 import org.apache.zest.api.structure.Module;
@@ -38,6 +38,6 @@ public class Context
 
     protected <T> T role( Object object, Class<T> roleType )
     {
-        return Qi4j.FUNCTION_COMPOSITE_INSTANCE_OF.map( (Composite) object ).newProxy( roleType );
+        return ZestAPI.FUNCTION_COMPOSITE_INSTANCE_OF.map( (Composite) object ).newProxy( roleType );
     }
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/build.gradle
----------------------------------------------------------------------
diff --git a/samples/rental/build.gradle b/samples/rental/build.gradle
index 6044b2b..c235514 100644
--- a/samples/rental/build.gradle
+++ b/samples/rental/build.gradle
@@ -25,17 +25,17 @@ apply plugin: 'jetty'
 // To run in an embedded Jetty use:
 //      ../../gradlew jettyRun
 // And then go to:
-//      http://localhost:8080/org.qi4j.sample.rental/rental/main
+//      http://localhost:8080/org.apache.zest.sample.rental/rental/main
 
 jar { manifest { name = "Apache Zest™ Sample - Car Rental" }}
 
 dependencies {
 
-  compile project( ":org.qi4j.core:org.qi4j.core.bootstrap" )
-  compile project( ":org.qi4j.extensions:org.qi4j.extension.valueserialization-orgjson" )
+  compile project( ":org.apache.zest.core:org.apache.zest.core.bootstrap" )
+  compile project( ":org.apache.zest.extensions:org.apache.zest.extension.valueserialization-orgjson" )
 
   providedCompile libraries.servlet_api
 
-  runtime project( ":org.qi4j.core:org.qi4j.core.runtime" )
+  runtime project( ":org.apache.zest.core:org.apache.zest.core.runtime" )
 
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/java/org/apache/zest/sample/rental/web/Page.java
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/Page.java b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/Page.java
index e04e79e..13baf6d 100644
--- a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/Page.java
+++ b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/Page.java
@@ -21,7 +21,7 @@ package org.apache.zest.sample.rental.web;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.List;
-import org.apache.zest.api.Qi4j;
+import org.apache.zest.api.ZestAPI;
 import org.apache.zest.api.composite.Composite;
 import org.apache.zest.api.concern.Concerns;
 import org.apache.zest.api.injection.scope.Uses;
@@ -41,7 +41,7 @@ public interface Page
     extends ServiceComposite
 {
     String XHTML = "http://www.w3.org/1999/xhtml";
-    String QI = "http://www.qi4j.org/ns/2009/quikit";
+    String QI = "http://zest.apache.org/ns/2009/quikit";
 
     /**
      * Returns the URL where the Page is mounted.
@@ -89,7 +89,7 @@ public interface Page
         private void execute( QuikitContext context, Element element, Element parent )
             throws RenderException
         {
-            Class<? extends Composite> compositeType = (Class<Composite>) first( Qi4j.FUNCTION_DESCRIPTOR_FOR
+            Class<? extends Composite> compositeType = (Class<Composite>) first( ZestAPI.FUNCTION_DESCRIPTOR_FOR
                                                                                      .map( context.page() )
                                                                                      .types() );
             try

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitResolver.java
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitResolver.java b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitResolver.java
index 5c47b1f..e77d39b 100644
--- a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitResolver.java
+++ b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitResolver.java
@@ -93,7 +93,7 @@ public class QuikitResolver
         }
         catch( Exception e )
         {
-            throw new UnsupportedOperationException( "Internal problem. Please report to qi4j-dev forum at Google Groups.", e  );
+            throw new UnsupportedOperationException( "Internal problem. Please report to dev@zest.apache.org mailing list.", e  );
         }
         input.setBaseURI( baseURI );
         input.setByteStream( resource );

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitServlet.java
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitServlet.java b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitServlet.java
index bdf9422..f7302a7 100644
--- a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitServlet.java
+++ b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/QuikitServlet.java
@@ -44,7 +44,7 @@ import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 import javax.xml.validation.Schema;
 import javax.xml.validation.SchemaFactory;
-import org.apache.zest.api.Qi4j;
+import org.apache.zest.api.ZestAPI;
 import org.apache.zest.api.composite.Composite;
 import org.apache.zest.api.service.ServiceFinder;
 import org.apache.zest.api.service.ServiceReference;
@@ -87,8 +87,8 @@ public class QuikitServlet
 
             ApplicationAssembler assembler = createApplicationAssembler( config );
 
-            Energy4Java qi4j = new Energy4Java();
-            application = qi4j.newApplication( assembler );
+            Energy4Java zest = new Energy4Java();
+            application = zest.newApplication( assembler );
             application.activate();
             Module module = application.findModule( "WebLayer", "PagesModule" );
             finder = module;
@@ -115,7 +115,7 @@ public class QuikitServlet
     private ApplicationAssembler createApplicationAssembler( ServletConfig config )
         throws ClassNotFoundException, NoSuchMethodException, InstantiationException, IllegalAccessException, InvocationTargetException
     {
-        String assemblerClassname = config.getInitParameter( "qi4j-assembler" );
+        String assemblerClassname = config.getInitParameter( "zest-assembler" );
         ClassLoader loader = getClass().getClassLoader();
         Class<?> assemblerClass = loader.loadClass( assemblerClassname );
         ApplicationAssembler assembler;
@@ -127,7 +127,7 @@ public class QuikitServlet
         else
         {
             Application.Mode mode;
-            String modeSetting = config.getInitParameter( "qi4j-application-mode" );
+            String modeSetting = config.getInitParameter( "zest-application-mode" );
             if( modeSetting == null )
             {
                 mode = Application.Mode.development;
@@ -194,7 +194,7 @@ public class QuikitServlet
     private void renderPage( Page page, String path, PrintWriter output, HttpServletRequest httpRequest )
         throws ParserConfigurationException, SAXException, IOException, RenderException, TransformerException
     {
-        Class<? extends Composite> pageClass = (Class<Composite>) first( Qi4j.FUNCTION_DESCRIPTOR_FOR
+        Class<? extends Composite> pageClass = (Class<Composite>) first( ZestAPI.FUNCTION_DESCRIPTOR_FOR
                                                                              .map( page ).types() );
 
         String pageName = pageClass.getSimpleName() + ".html";

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/java/org/apache/zest/sample/rental/web/UrlService.java
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/UrlService.java b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/UrlService.java
index 152d1d1..e6c5e6a 100644
--- a/samples/rental/src/main/java/org/apache/zest/sample/rental/web/UrlService.java
+++ b/samples/rental/src/main/java/org/apache/zest/sample/rental/web/UrlService.java
@@ -21,7 +21,7 @@ package org.apache.zest.sample.rental.web;
 import org.apache.zest.api.injection.scope.Structure;
 import org.apache.zest.api.mixin.Mixins;
 import org.apache.zest.api.service.ServiceComposite;
-import org.apache.zest.spi.Qi4jSPI;
+import org.apache.zest.spi.ZestSPI;
 
 @Mixins( UrlService.UrlServiceMixin.class )
 public interface UrlService
@@ -35,7 +35,7 @@ public interface UrlService
         implements UrlService
     {
         @Structure
-        Qi4jSPI spi;
+        ZestSPI spi;
 
         private String baseUri;
 

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/BookingPage.html
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/BookingPage.html b/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/BookingPage.html
index e777524..8cbac0a 100644
--- a/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/BookingPage.html
+++ b/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/BookingPage.html
@@ -15,7 +15,7 @@
   limitations under the License.
 -->
 <html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en"
-      xmlns:qi="http://www.qi4j.org/ns/2009/quikit"
+      xmlns:qi="http://zest.apache.org/ns/2009/quikit"
       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
       xsi:schemaLocation="http://www.w3.org/1999/xhtml
                           http://www.w3.org/2002/08/xhtml/xhtml1-strict.xsd">

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/MainPage.html
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/MainPage.html b/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/MainPage.html
index a86b8ad..1f2980e 100644
--- a/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/MainPage.html
+++ b/samples/rental/src/main/resources/org/apache/zest/sample/rental/web/MainPage.html
@@ -16,7 +16,7 @@
   limitations under the License.
 -->
 <html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en"
-      xmlns:qi="http://www.qi4j.org/ns/2009/quikit"
+      xmlns:qi="http://zest.apache.org/ns/2009/quikit"
       xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
       xsi:schemaLocation="http://www.w3.org/1999/xhtml
                           http://www.w3.org/2002/08/xhtml/xhtml1-strict.xsd">

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/rental/src/main/webapp/WEB-INF/web.xml
----------------------------------------------------------------------
diff --git a/samples/rental/src/main/webapp/WEB-INF/web.xml b/samples/rental/src/main/webapp/WEB-INF/web.xml
index 083b03b..a2ab0bf 100644
--- a/samples/rental/src/main/webapp/WEB-INF/web.xml
+++ b/samples/rental/src/main/webapp/WEB-INF/web.xml
@@ -26,7 +26,7 @@
     <servlet-name>QuikitServlet</servlet-name>
     <servlet-class>org.apache.zest.sample.rental.web.QuikitServlet</servlet-class>
     <init-param>
-      <param-name>qi4j-assembler</param-name>
+      <param-name>zest-assembler</param-name>
       <param-value>org.apache.zest.sample.rental.web.assembly.RentalApplicationAssembler</param-value>
     </init-param>
     <load-on-startup>1</load-on-startup>

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/sql-support/build.gradle
----------------------------------------------------------------------
diff --git a/samples/sql-support/build.gradle b/samples/sql-support/build.gradle
index 21eba5b..d31576d 100644
--- a/samples/sql-support/build.gradle
+++ b/samples/sql-support/build.gradle
@@ -23,19 +23,19 @@ jar { manifest { name = "Apache Zest™ Sample - SQL Support" }}
 
 dependencies {
 
-    compile project( ":org.qi4j.core:org.qi4j.core.bootstrap" )
-    compile project( ":org.qi4j.libraries:org.qi4j.library.sql-dbcp" )
-    compile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-preferences" )
-    compile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-sql" )
-    compile project( ":org.qi4j.extensions:org.qi4j.extension.indexing-sql" )
+    compile project( ":org.apache.zest.core:org.apache.zest.core.bootstrap" )
+    compile project( ":org.apache.zest.libraries:org.apache.zest.library.sql-dbcp" )
+    compile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-preferences" )
+    compile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-sql" )
+    compile project( ":org.apache.zest.extensions:org.apache.zest.extension.indexing-sql" )
 
-    runtime project(":org.qi4j.core:org.qi4j.core.runtime")
+    runtime project(":org.apache.zest.core:org.apache.zest.core.runtime")
     runtime libraries.postgres
     runtime libraries.slf4j_simple
 
 }
 
 task( runSample, dependsOn: 'classes', type: JavaExec ) {
-    main = 'org.qi4j.sample.sqlsupport.Main'
+    main = 'org.apache.zest.sample.sqlsupport.Main'
     classpath = sourceSets.main.runtimeClasspath
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/samples/swing/build.gradle
----------------------------------------------------------------------
diff --git a/samples/swing/build.gradle b/samples/swing/build.gradle
index 918363c..ff33e31 100644
--- a/samples/swing/build.gradle
+++ b/samples/swing/build.gradle
@@ -22,5 +22,5 @@ description = "Sample of how to use the Swing bindings."
 jar { manifest { name = "Apache Zest™ Sample - Swing Bindings" }}
 
 dependencies {
-  compile(project(":org.qi4j.core:org.qi4j.core.bootstrap"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.bootstrap"))
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/settings.gradle
----------------------------------------------------------------------
diff --git a/settings.gradle b/settings.gradle
index a66fd66..c017e1f 100644
--- a/settings.gradle
+++ b/settings.gradle
@@ -106,7 +106,7 @@ include 'core:functional',
         'tests:regression',
         'tests:performance'
 
-rootProject.name = "org.qi4j"
+rootProject.name = "org.apache.zest"
 
 validateProject(rootProject, "")
 
@@ -117,9 +117,9 @@ def validateProject(project, parentName)
     {
         assert project.buildFile.isFile()
     }
-    if( parentName == 'org.qi4j.libraries' )
+    if( parentName == 'org.apache.zest.libraries' )
     {
-        parentName = 'org.qi4j.library'
+        parentName = 'org.apache.zest.library'
     }
     if( parentName.endsWith('s') )
     {

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/build.gradle
----------------------------------------------------------------------
diff --git a/tests/performance/build.gradle b/tests/performance/build.gradle
index 8ebd698..95f2095 100644
--- a/tests/performance/build.gradle
+++ b/tests/performance/build.gradle
@@ -27,7 +27,7 @@ sourceSets {
 
 dependencies {
 
-    compile project( ":org.qi4j.core:org.qi4j.core.bootstrap" )
+    compile project( ":org.apache.zest.core:org.apache.zest.core.bootstrap" )
     compile libraries.junit
     compile libraries.slf4j_api
 
@@ -36,17 +36,17 @@ dependencies {
     perfCompile sourceSets.test.output
     perfRuntime configurations.testRuntime
     
-    perfCompile project( ":org.qi4j.core:org.qi4j.core.testsupport" )
-    perfCompile project( ":org.qi4j.libraries:org.qi4j.library.sql-dbcp" )
-    perfCompile project( ':org.qi4j.extensions:org.qi4j.extension.valueserialization-orgjson' )
-    perfCompile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-memory" )
-    perfCompile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-jdbm" )
-    perfCompile project( ":org.qi4j.extensions:org.qi4j.extension.entitystore-sql" )
-    perfCompile project( ":org.qi4j.extensions:org.qi4j.extension.cache-ehcache" )
-    perfCompile project( ":org.qi4j.extensions:org.qi4j.extension.indexing-rdf" )
+    perfCompile project( ":org.apache.zest.core:org.apache.zest.core.testsupport" )
+    perfCompile project( ":org.apache.zest.libraries:org.apache.zest.library.sql-dbcp" )
+    perfCompile project( ':org.apache.zest.extensions:org.apache.zest.extension.valueserialization-orgjson' )
+    perfCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-memory" )
+    perfCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-jdbm" )
+    perfCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.entitystore-sql" )
+    perfCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.cache-ehcache" )
+    perfCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.indexing-rdf" )
     perfCompile libraries.derby
 
-    perfRuntime project(":org.qi4j.core:org.qi4j.core.runtime")
+    perfRuntime project(":org.apache.zest.core:org.apache.zest.core.runtime")
     perfRuntime libraries.logback
 
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/src/main/java/org/apache/zest/test/performance/entitystore/AbstractEntityStorePerformanceTest.java
----------------------------------------------------------------------
diff --git a/tests/performance/src/main/java/org/apache/zest/test/performance/entitystore/AbstractEntityStorePerformanceTest.java b/tests/performance/src/main/java/org/apache/zest/test/performance/entitystore/AbstractEntityStorePerformanceTest.java
index abde3ee..b35ace8 100644
--- a/tests/performance/src/main/java/org/apache/zest/test/performance/entitystore/AbstractEntityStorePerformanceTest.java
+++ b/tests/performance/src/main/java/org/apache/zest/test/performance/entitystore/AbstractEntityStorePerformanceTest.java
@@ -75,7 +75,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( SimpleProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
 
             for( int i = 0; i < 10000; i++ )
             {
@@ -112,7 +112,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( SimpleProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
 
             profile( new Callable<Void>()
             {
@@ -162,7 +162,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( SimpleProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
             profile( new Callable<Void>()
             {
                 @Override
@@ -212,7 +212,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( ComplexProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
             profile( new Callable<Void>()
             {
                 @Override
@@ -257,7 +257,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( ComplexProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
             profile( new Callable<Void>()
             {
                 @Override
@@ -307,7 +307,7 @@ public abstract class AbstractEntityStorePerformanceTest
                     module.entities( ComplexProduct.class );
                 }
             };
-            createQi4jRuntime( assembler );
+            createZestRuntime( assembler );
             {
                 int bulk = 0;
                 UnitOfWork uow = module.newUnitOfWork( newUsecase( "readEntityWithComplexType PREPARE " + bulk ) );
@@ -387,10 +387,10 @@ public abstract class AbstractEntityStorePerformanceTest
         System.out.println( "Report written to " + name );
     }
 
-    private void createQi4jRuntime( Assembler testSetup )
+    private void createZestRuntime( Assembler testSetup )
         throws Exception
     {
-        Energy4Java qi4j = new Energy4Java();
+        Energy4Java zest = new Energy4Java();
         Assembler[][][] assemblers = new Assembler[][][]
         {
             {
@@ -399,7 +399,7 @@ public abstract class AbstractEntityStorePerformanceTest
                 }
             }
         };
-        application = qi4j.newApplication( new ApplicationAssemblerAdapter( assemblers )
+        application = zest.newApplication( new ApplicationAssemblerAdapter( assemblers )
         {
         } );
         application.activate();

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/src/perf/java/org/apache/zest/test/performance/entitystore/sql/PostgreSQLEntityStorePerformanceTest.java
----------------------------------------------------------------------
diff --git a/tests/performance/src/perf/java/org/apache/zest/test/performance/indexing/rdf/QueryPerformanceTest.java b/tests/performance/src/perf/java/org/apache/zest/test/performance/indexing/rdf/QueryPerformanceTest.java
index 101ee63..321f30f 100644
--- a/tests/performance/src/perf/java/org/apache/zest/test/performance/indexing/rdf/QueryPerformanceTest.java
+++ b/tests/performance/src/perf/java/org/apache/zest/test/performance/indexing/rdf/QueryPerformanceTest.java
@@ -70,57 +70,57 @@ public class QueryPerformanceTest
 
     private Application application;
     private Module module;
-    private static final String QUERY1 = "PREFIX ns0: <urn:qi4j:type:org.qi4j.api.entity.Identity#> \n"
+    private static final String QUERY1 = "PREFIX ns0: <urn:zest:type:org.apache.zest.api.entity.Identity#> \n"
                                          + "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> \n"
                                          + "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> \n"
-                                         + "PREFIX ns1: <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
+                                         + "PREFIX ns1: <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
                                          + "SELECT ?entityType ?identity\n"
                                          + "WHERE {\n"
-                                         + "?entityType rdfs:subClassOf <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
+                                         + "?entityType rdfs:subClassOf <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
                                          + "?entity rdf:type ?entityType. \n"
                                          + "?entity ns0:identity ?identity. \n"
                                          + "?entity ns1:name \"Lead64532\". \n"
                                          + "}";
-    private static final String QUERY2 = "PREFIX ns0: <urn:qi4j:type:org.qi4j.api.entity.Identity#> \n"
+    private static final String QUERY2 = "PREFIX ns0: <urn:zest:type:org.apache.zest.api.entity.Identity#> \n"
                                          + "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> \n"
                                          + "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> \n"
-                                         + "PREFIX ns1: <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
+                                         + "PREFIX ns1: <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
                                          + "SELECT ?entityType ?identity\n"
                                          + "WHERE {\n"
-                                         + "?entityType rdfs:subClassOf <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
+                                         + "?entityType rdfs:subClassOf <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
                                          + "?entity rdf:type ?entityType. \n"
                                          + "?entity ns0:identity ?identity. \n"
                                          + "?entity ns1:name \"Lead98276\". \n"
                                          + "}";
-    private static final String QUERY3 = "PREFIX ns0: <urn:qi4j:type:org.qi4j.api.entity.Identity#> \n"
+    private static final String QUERY3 = "PREFIX ns0: <urn:zest:type:org.apache.zest.api.entity.Identity#> \n"
                                          + "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> \n"
                                          + "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> \n"
-                                         + "PREFIX ns1: <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
+                                         + "PREFIX ns1: <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
                                          + "SELECT ?entityType ?identity\n"
                                          + "WHERE {\n"
-                                         + "?entityType rdfs:subClassOf <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
+                                         + "?entityType rdfs:subClassOf <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
                                          + "?entity rdf:type ?entityType. \n"
                                          + "?entity ns0:identity ?identity. \n"
                                          + "?entity ns1:name \"Lead2\". \n"
                                          + "}";
-    private static final String QUERY4 = "PREFIX ns0: <urn:qi4j:type:org.qi4j.api.entity.Identity#> \n"
+    private static final String QUERY4 = "PREFIX ns0: <urn:zest:type:org.apache.zest.api.entity.Identity#> \n"
                                          + "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> \n"
                                          + "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> \n"
-                                         + "PREFIX ns1: <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
+                                         + "PREFIX ns1: <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
                                          + "SELECT ?entityType ?identity\n"
                                          + "WHERE {\n"
-                                         + "?entityType rdfs:subClassOf <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
+                                         + "?entityType rdfs:subClassOf <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
                                          + "?entity rdf:type ?entityType. \n"
                                          + "?entity ns0:identity ?identity. \n"
                                          + "?entity ns1:name \"Lead14332\". \n"
                                          + "}";
-    private static final String QUERY5 = "PREFIX ns0: <urn:qi4j:type:org.qi4j.api.entity.Identity#> \n"
+    private static final String QUERY5 = "PREFIX ns0: <urn:zest:type:org.apache.zest.api.entity.Identity#> \n"
                                          + "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> \n"
                                          + "PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#> \n"
-                                         + "PREFIX ns1: <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
+                                         + "PREFIX ns1: <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead#> \n"
                                          + "SELECT ?entityType ?identity\n"
                                          + "WHERE {\n"
-                                         + "?entityType rdfs:subClassOf <urn:qi4j:type:org.qi4j.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
+                                         + "?entityType rdfs:subClassOf <urn:zest:type:org.apache.zest.test.performance.indexing.rdf.QueryPerformanceTest-Lead>. \n"
                                          + "?entity rdf:type ?entityType. \n"
                                          + "?entity ns0:identity ?identity. \n"
                                          + "?entity ns1:name \"Lead632\". \n"
@@ -131,8 +131,8 @@ public class QueryPerformanceTest
     public void setup()
         throws Exception
     {
-        Energy4Java qi4j = new Energy4Java();
-        application = qi4j.newApplication( this );
+        Energy4Java zest = new Energy4Java();
+        application = zest.newApplication( this );
         module = application.findModule( LAYER_DOMAIN, MODULE_DOMAIN );
         application.activate();
         indexingDataDir = module.findService( RdfIndexingService.class ).get().dataDir();

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/InvocationPerformanceTest.java
----------------------------------------------------------------------
diff --git a/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/InvocationPerformanceTest.java b/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/InvocationPerformanceTest.java
index 01e2913..664607d 100644
--- a/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/InvocationPerformanceTest.java
+++ b/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/InvocationPerformanceTest.java
@@ -28,7 +28,7 @@ import org.apache.zest.api.concern.Concerns;
 import org.apache.zest.api.mixin.Mixins;
 import org.apache.zest.bootstrap.AssemblyException;
 import org.apache.zest.bootstrap.ModuleAssembly;
-import org.apache.zest.test.AbstractQi4jTest;
+import org.apache.zest.test.AbstractZestTest;
 
 /**
  * Invocation performance test.
@@ -41,7 +41,7 @@ import org.apache.zest.test.AbstractQi4jTest;
  * </p>
  */
 public class InvocationPerformanceTest
-    extends AbstractQi4jTest
+    extends AbstractZestTest
 {
     @Override
     public void assemble( ModuleAssembly module )

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/PropertyMixinInvocationPerformanceTest.java
----------------------------------------------------------------------
diff --git a/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/PropertyMixinInvocationPerformanceTest.java b/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/PropertyMixinInvocationPerformanceTest.java
index c13d6ee..d6bfcc6 100644
--- a/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/PropertyMixinInvocationPerformanceTest.java
+++ b/tests/performance/src/perf/java/org/apache/zest/test/performance/runtime/composite/PropertyMixinInvocationPerformanceTest.java
@@ -28,7 +28,7 @@ import org.apache.zest.api.mixin.Mixins;
 import org.apache.zest.api.property.Property;
 import org.apache.zest.bootstrap.AssemblyException;
 import org.apache.zest.bootstrap.ModuleAssembly;
-import org.apache.zest.test.AbstractQi4jTest;
+import org.apache.zest.test.AbstractZestTest;
 
 /**
  * PropertyMixin invocation performance test.
@@ -37,7 +37,7 @@ import org.apache.zest.test.AbstractQi4jTest;
  * </p>
  */
 public class PropertyMixinInvocationPerformanceTest
-    extends AbstractQi4jTest
+    extends AbstractZestTest
 {
     @Override
     public void assemble( ModuleAssembly module )

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/regression/build.gradle
----------------------------------------------------------------------
diff --git a/tests/regression/build.gradle b/tests/regression/build.gradle
index 73bb428..ceeac7a 100644
--- a/tests/regression/build.gradle
+++ b/tests/regression/build.gradle
@@ -22,17 +22,17 @@ description = "Apache Zest™ Regression Tests are added by community members wh
 jar { manifest { name = "Apache Zest™ Tests - Regression" }}
 
 dependencies {
-  compile(project(":org.qi4j.core:org.qi4j.core.api"))
-  compile(project(":org.qi4j.core:org.qi4j.core.bootstrap"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.api"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.bootstrap"))
   compile(libraries.slf4j_api)
   compile(libraries.junit)
   runtime(libraries.asm)
   runtime(libraries.asm_commons)
   runtime(libraries.slf4j_simple)
-  compile(project(":org.qi4j.core:org.qi4j.core.testsupport"))
-  compile(project(":org.qi4j.libraries:org.qi4j.library.logging"))
-  compile(project(":org.qi4j.extensions:org.qi4j.extension.indexing-rdf"))
-  compile(project(":org.qi4j.extensions:org.qi4j.extension.entitystore-jdbm"))
-  runtime(project(":org.qi4j.core:org.qi4j.core.spi"))
-  runtime(project(":org.qi4j.core:org.qi4j.core.runtime"))
+  compile(project(":org.apache.zest.core:org.apache.zest.core.testsupport"))
+  compile(project(":org.apache.zest.libraries:org.apache.zest.library.logging"))
+  compile(project(":org.apache.zest.extensions:org.apache.zest.extension.indexing-rdf"))
+  compile(project(":org.apache.zest.extensions:org.apache.zest.extension.entitystore-jdbm"))
+  runtime(project(":org.apache.zest.core:org.apache.zest.core.spi"))
+  runtime(project(":org.apache.zest.core:org.apache.zest.core.runtime"))
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/regression/src/main/java/org/apache/zest/test/regression/niclas2/ConcernsOnPropertyTest.java
----------------------------------------------------------------------
diff --git a/tests/regression/src/main/java/org/apache/zest/test/regression/niclas2/ConcernsOnPropertyTest.java b/tests/regression/src/main/java/org/apache/zest/test/regression/niclas2/ConcernsOnPropertyTest.java
index f3e3f50..b063291 100644
--- a/tests/regression/src/main/java/org/apache/zest/test/regression/niclas2/ConcernsOnPropertyTest.java
+++ b/tests/regression/src/main/java/org/apache/zest/test/regression/niclas2/ConcernsOnPropertyTest.java
@@ -30,11 +30,11 @@ import org.apache.zest.api.sideeffect.SideEffectOf;
 import org.apache.zest.api.sideeffect.SideEffects;
 import org.apache.zest.bootstrap.AssemblyException;
 import org.apache.zest.bootstrap.ModuleAssembly;
-import org.apache.zest.test.AbstractQi4jTest;
+import org.apache.zest.test.AbstractZestTest;
 
 
 public class ConcernsOnPropertyTest
-    extends AbstractQi4jTest
+    extends AbstractZestTest
 {
     public void assemble( ModuleAssembly module )
         throws AssemblyException

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tools/envisage/build.gradle
----------------------------------------------------------------------
diff --git a/tools/envisage/build.gradle b/tools/envisage/build.gradle
index 65cca01..2b7618f 100644
--- a/tools/envisage/build.gradle
+++ b/tools/envisage/build.gradle
@@ -23,26 +23,26 @@ jar { manifest { name = "Apache Zest™ Envisage" }}
 
 dependencies {
 
-  compile project( ":org.qi4j.core:org.qi4j.core.bootstrap" )
-  compile project( ":org.qi4j.tools:org.qi4j.tool.model-detail" )
+  compile project( ":org.apache.zest.core:org.apache.zest.core.bootstrap" )
+  compile project( ":org.apache.zest.tools:org.apache.zest.tool.model-detail" )
   compile libraries.jgoodies_looks
   compile libraries.pdfbox
   compile libraries.prefuse
 
-  testCompile project( ":org.qi4j.core:org.qi4j.core.testsupport" )
-  testCompile project( ":org.qi4j.extensions:org.qi4j.extension.indexing-rdf" )
+  testCompile project( ":org.apache.zest.core:org.apache.zest.core.testsupport" )
+  testCompile project( ":org.apache.zest.extensions:org.apache.zest.extension.indexing-rdf" )
 
-  testRuntime project( ":org.qi4j.core:org.qi4j.core.runtime" )
+  testRuntime project( ":org.apache.zest.core:org.apache.zest.core.runtime" )
   testRuntime libraries.logback
 
 }
 
 task(runSample, dependsOn: 'testClasses', type: JavaExec) {
-    main = 'org.qi4j.envisage.sample.EnvisageSample'
+    main = 'org.apache.zest.envisage.sample.EnvisageSample'
     classpath = sourceSets.test.runtimeClasspath
 }
 
 task(runSchool, dependsOn: 'testClasses', type: JavaExec) {
-    main = 'org.qi4j.envisage.school.EnvisageSchoolSample'
+    main = 'org.apache.zest.envisage.school.EnvisageSchoolSample'
     classpath = sourceSets.test.runtimeClasspath
 }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tools/envisage/dev-status.xml
----------------------------------------------------------------------
diff --git a/tools/envisage/dev-status.xml b/tools/envisage/dev-status.xml
index 4458bbb..a0d7558 100644
--- a/tools/envisage/dev-status.xml
+++ b/tools/envisage/dev-status.xml
@@ -15,10 +15,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 -->
-<module xmlns="http://www.qi4j.org/schemas/2008/dev-status/1"
+<module xmlns="http://zest.apache.org/schemas/2008/dev-status/1"
         xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-        xsi:schemaLocation="http://www.qi4j.org/schemas/2008/dev-status/1
-        http://www.qi4j.org/schemas/2008/dev-status/1/dev-status.xsd">
+        xsi:schemaLocation="http://zest.apache.org/schemas/2008/dev-status/1
+        http://zest.apache.org/schemas/2008/dev-status/1/dev-status.xsd">
   <status>
     <!--none,early,beta,stable,mature-->
     <codebase>stable</codebase>

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tools/envisage/src/main/java/org/apache/zest/envisage/Envisage.java
----------------------------------------------------------------------
diff --git a/tools/envisage/src/main/java/org/apache/zest/envisage/Envisage.java b/tools/envisage/src/main/java/org/apache/zest/envisage/Envisage.java
index f7cb03f..cc1f66c 100644
--- a/tools/envisage/src/main/java/org/apache/zest/envisage/Envisage.java
+++ b/tools/envisage/src/main/java/org/apache/zest/envisage/Envisage.java
@@ -33,7 +33,7 @@ import javax.swing.UnsupportedLookAndFeelException;
 import org.apache.zest.api.structure.ApplicationDescriptor;
 
 /**
- * Qi4J Application Viewer
+ * Apache Zest Application Viewer
  */
 public class Envisage
 {
@@ -85,7 +85,7 @@ public class Envisage
                     @Override
                     public void run()
                     {
-                        mainFrame.initQi4J();
+                        mainFrame.initZest();
                     }
                 } );
             }

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tools/envisage/src/main/java/org/apache/zest/envisage/EnvisageFrame.java
----------------------------------------------------------------------
diff --git a/tools/envisage/src/main/java/org/apache/zest/envisage/EnvisageFrame.java b/tools/envisage/src/main/java/org/apache/zest/envisage/EnvisageFrame.java
index 83c1938..5e5f4c4 100644
--- a/tools/envisage/src/main/java/org/apache/zest/envisage/EnvisageFrame.java
+++ b/tools/envisage/src/main/java/org/apache/zest/envisage/EnvisageFrame.java
@@ -123,14 +123,14 @@ public final class EnvisageFrame
         contentPane.add( graphSplitPane, BorderLayout.CENTER );
     }
 
-    public void initQi4J()
+    public void initZest()
     {
         modelSplitPane.setDividerLocation( 300 );
         graphSplitPane.setDividerLocation( 384 );
 
         descriptor = ApplicationDetailDescriptorBuilder.createApplicationDetailDescriptor( application );
-        treeModelPane.initQi4J( descriptor );
-        graphPane.initQi4J( descriptor );
+        treeModelPane.initZest( descriptor );
+        graphPane.initZest( descriptor );
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tools/envisage/src/main/java/org/apache/zest/envisage/detail/DependencyPane.form
----------------------------------------------------------------------
diff --git a/tools/envisage/src/main/java/org/apache/zest/envisage/detail/DependencyPane.form b/tools/envisage/src/main/java/org/apache/zest/envisage/detail/DependencyPane.form
index ec19db6..42d049f 100644
--- a/tools/envisage/src/main/java/org/apache/zest/envisage/detail/DependencyPane.form
+++ b/tools/envisage/src/main/java/org/apache/zest/envisage/detail/DependencyPane.form
@@ -1,24 +1,8 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<!--
-  Licensed to the Apache Software Foundation (ASF) under one or more
-  contributor license agreements.  See the NOTICE file distributed with
-  this work for additional information regarding copyright ownership.
-  The ASF licenses this file to You under the Apache License, Version 2.0
-  (the "License"); you may not use this file except in compliance with
-  the License.  You may obtain a copy of the License at
-  
-  http://www.apache.org/licenses/LICENSE-2.0
-  
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
--->
 <form xmlns="http://www.intellij.com/uidesigner/form/" version="1" bind-to-class="org.apache.zest.envisage.detail.DependencyPane">
   <grid id="27dc6" binding="contentPane" layout-manager="BorderLayout" hgap="0" vgap="0">
     <constraints>
-      <xy x="20" y="20" width="545" height="400"/>
+      <xy x="20" y="20" width="598" height="415"/>
     </constraints>
     <properties/>
     <border type="none"/>
@@ -56,7 +40,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_ClassName.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_ClassName.Text"/>
                 </properties>
               </component>
               <hspacer id="ef53d">
@@ -77,7 +61,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_Optional.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_Optional.Text"/>
                 </properties>
               </component>
               <component id="dcc55" class="javax.swing.JLabel">
@@ -86,7 +70,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_Annotation.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_Annotation.Text"/>
                 </properties>
               </component>
               <vspacer id="90e22">
@@ -113,7 +97,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_InjectionType.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_InjectionType.Text"/>
                 </properties>
               </component>
               <component id="d289f" class="javax.swing.JLabel" binding="classNameLabel">
@@ -164,7 +148,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_Injection.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_Injection.Text"/>
                 </properties>
               </component>
               <scrollpane id="8506a">
@@ -193,7 +177,7 @@
                   <gridbag weightx="0.0" weighty="0.0"/>
                 </constraints>
                 <properties>
-                  <text resource-bundle="org/qi4j/envisage/detail/DependencyPane" key="CTL_InjectedServices.Text"/>
+                  <text resource-bundle="org/apache/zest/envisage/detail/DependencyPane" key="CTL_InjectedServices.Text"/>
                 </properties>
               </component>
               <component id="fb56b" class="javax.swing.JSeparator">
diff --git a/tests/performance/src/perf/java/org/apache/zest/test/performance/entitystore/sql/PostgreSQLEntityStorePerformanceTest.java b/tests/performance/src/perf/java/org/apache/zest/test/performance/entitystore/sql/PostgreSQLEntityStorePerformanceTest.java
index f74d246..47238a8 100644
--- a/tests/performance/src/perf/java/org/apache/zest/test/performance/entitystore/sql/PostgreSQLEntityStorePerformanceTest.java
+++ b/tests/performance/src/perf/java/org/apache/zest/test/performance/entitystore/sql/PostgreSQLEntityStorePerformanceTest.java
@@ -100,7 +100,7 @@ public class PostgreSQLEntityStorePerformanceTest
         finally
         {
 
-            Energy4Java qi4j = new Energy4Java();
+            Energy4Java zest = new Energy4Java();
             Assembler[][][] assemblers = new Assembler[][][]
             {
                 {
@@ -109,7 +109,7 @@ public class PostgreSQLEntityStorePerformanceTest
                     }
                 }
             };
-            Application application = qi4j.newApplication( new ApplicationAssemblerAdapter( assemblers )
+            Application application = zest.newApplication( new ApplicationAssemblerAdapter( assemblers )
             {
             } );
             application.activate();
@@ -121,7 +121,7 @@ public class PostgreSQLEntityStorePerformanceTest
             {
                 SQLConfiguration config = uow.get( SQLConfiguration.class,
                                                    PostgreSQLEntityStoreAssembler.DEFAULT_ENTITYSTORE_IDENTITY );
                 // TODO fix AbstractEntityStorePerformanceTest to extend from AbstractQi4jTest
                 Connection connection = null; // SQLUtil.getConnection( this.serviceLocator );
                 String schemaName = config.schemaName().get();
                 if( schemaName == null )

http://git-wip-us.apache.org/repos/asf/zest-java/blob/95d31c05/tests/performance/src/perf/java/org/apache/zest/test/performance/indexing/rdf/QueryPerformanceTest.java
----------------------------------------------------------------------
@@ -121,7 +121,7 @@ public class PostgreSQLEntityStorePerformanceTest
                 SQLConfiguration config = uow.get( SQLConfiguration.class,
                                                    PostgreSQLEntityStoreAssembler.DEFAULT_ENTITYSTORE_IDENTITY );
-                // TODO fix AbstractEntityStorePerformanceTest to extend from AbstractQi4jTest
+                // TODO fix AbstractEntityStorePerformanceTest to extend from AbstractZestTest
                 Connection connection = null; // SQLUtil.getConnection( this.serviceLocator );
                 String schemaName = config.schemaName().get();